# Search N Act

[github](https://github.com/eaybek/sna/)  
[PyPi](https://pypi.org/project/sna/)  

you can do:
    search and replace
    search and create
    search and open
    search and anything...

